@@ -1,6 +1,6 @@
 /*
  * common.h -- Common definitions for X and Windows NT versions of XBoard
- * $Id: common.h,v 1.61 1998/06/21 01:12:29 mann Exp $
+ * $Id: common.h,v 1.64 1999/12/04 01:53:01 mann Exp $
  *
  * Copyright 1991 by Digital Equipment Corporation, Maynard, Massachusetts.
  * Enhancements Copyright 1992-95 Free Software Foundation, Inc.
@@ -121,6 +121,26 @@ int pclose(FILE *);
 #define BELLCHAR                '\007'
 #define NULLCHAR                '\000'
 
+/* Zippy defaults */
+#define ZIPPY_TALK FALSE
+#define ZIPPY_PLAY FALSE
+#define ZIPPY_LINES "yow.lines"
+#define ZIPPY_PINHEAD ""
+#define ZIPPY_PASSWORD ""
+#define ZIPPY_PASSWORD2 ""
+#define ZIPPY_WRONG_PASSWORD ""
+#define ZIPPY_ACCEPT_ONLY ""
+#define ZIPPY_USE_I TRUE
+#define ZIPPY_BUGHOUSE 0
+#define ZIPPY_NOPLAY_CRAFTY FALSE
+#define ZIPPY_GAME_END "gameend\n"
+#define ZIPPY_GAME_START ""
+#define ZIPPY_ADJOURN FALSE
+#define ZIPPY_ABORT FALSE
+#define ZIPPY_VARIANTS "normal"
+#define ZIPPY_MAX_GAMES 0
+#define ZIPPY_REPLAY_TIMEOUT 120
+
 typedef enum {
     BeginningOfGame, MachinePlaysWhite, MachinePlaysBlack,
     AnalyzeMode, AnalyzeFile, TwoMachinesPlay,
@@ -159,10 +179,41 @@ typedef enum {
 
 typedef enum {
     ColorShout, ColorSShout, ColorChannel1, ColorChannel, ColorKibitz,
-    ColorTell, ColorChallenge, ColorRequest, ColorNormal, ColorNone, 
-    NColorClasses
+    ColorTell, ColorChallenge, ColorRequest, ColorSeek, ColorNormal,
+    ColorNone, NColorClasses
 } ColorClass;
 
+/* Names for chess variants, not necessarily supported */
+typedef enum {
+    VariantNormal,       /* Normal chess */
+    VariantLoadable,     /* "loadgame" command allowed (not really a variant)*/
+    VariantWildCastle,   /* Shuffle chess where king can castle from d file */
+    VariantNoCastle,     /* Shuffle chess with no castling at all */
+    VariantFischeRandom, /* FischeRandom */
+    VariantBughouse,     /* Bughouse, ICC/FICS rules */
+    VariantCrazyhouse,   /* Crazyhouse, ICC/FICS rules */
+    VariantLosers,       /* Win by losing all pieces or getting mated (ICC) */
+    VariantSuicide,      /* Win by losing all pieces including king (FICS) */
+    VariantTwoKings,     /* Weird ICC wild 9 */
+    VariantKriegspiel,   /* Kriegspiel, no special support provided */
+    VariantAtomic        /* Possible future extension */
+} VariantClass;
+
+#define VARIANT_NAMES { \
+  "normal", \
+  "normal", \
+  "wildcastle", \
+  "nocastle", \
+  "fischerandom", \
+  "bughouse", \
+  "crazyhouse", \
+  "losers", \
+  "suicide", \
+  "twokings", \
+  "kriegspiel", \
+  "atomic" \
+}
+
 typedef struct {
 #if !defined(_amigados)
     char *whitePieceColor;
@@ -265,6 +316,7 @@ typedef struct {
     char *colorTell;
     char *colorChallenge;
     char *colorRequest;
+    char *colorSeek;
     char *colorNormal;
     Boolean reuseFirst;
     Boolean reuseSecond;
@@ -272,9 +324,29 @@ typedef struct {
     Boolean animate;	/* If True, animate non-mouse moves */
     int animSpeed;	/* Delay in milliseconds between animation frames */
     Boolean popupMoveErrors;
+    Boolean popupExitMessage;
     int showJail;
     Boolean highlightLastMove;
     Boolean highlightDragging;
+    int fontSizeTolerance; /* xboard only */
+#if ZIPPY
+    char *zippyLines;
+    char *zippyPinhead;
+    char *zippyPassword;
+    char *zippyPassword2;
+    char *zippyWrongPassword;
+    char *zippyAcceptOnly;
+    int zippyUseI;
+    int zippyBughouse;
+    int zippyNoplayCrafty;
+    char *zippyGameEnd;
+    char *zippyGameStart;
+    int zippyAdjourn;
+    int zippyAbort;
+    char *zippyVariants;
+    int zippyMaxGames;
+    int zippyReplayTimeout; /*seconds*/
+#endif
 } AppData, *AppDataPtr;
 
 extern AppData appData;
@@ -295,6 +367,7 @@ typedef struct {
     char *extraTags;    /* NULL or "[Tag \"Value\"]\n", etc. */
     int whiteRating;    /* -1 if unknown */
     int blackRating;    /* -1 if unknown */
+    VariantClass variant;
 } GameInfo;
 
 
